<template>
  <div class="app-container">
    <el-dialog
      title="添加学员"
      :visible.sync="dialogVisible"
      width="30%"
      :before-close="handleClose"
    >
      <el-form ref="form" :model="createData" label-width="100px">
        <el-form-item label="姓名" style="width: 400px">
          <el-input v-model="createData.playerName" size="small"></el-input>
        </el-form-item>
        <el-form-item label="性别" style="width: 400px">
          <el-input v-model="createData.gender" size="small"></el-input>
        </el-form-item>
        <el-form-item label="生日">
          <el-date-picker
            v-model="createData.birthday"
            type="date"
            placeholder="选择日期"
            size="small"
          >
          </el-date-picker>
        </el-form-item>
        <el-form-item label="联系电话" style="width: 400px">
          <el-input v-model="createData.mobile" size="small"></el-input>
        </el-form-item>
        <el-form-item label="课包">
          <el-select
            v-model="createData.saleMan.id"
            filterable
            clearable
            placeholder="请选择"
            size="small"
          >
            <el-option
              v-for="item in saleManList"
              :key="item.id"
              :label="item.name"
              :value="item.id"
            >
            </el-option>
          </el-select>
        </el-form-item>
        <el-form-item label="课时" style="width: 400px">
          <el-input-number v-model="num" size="small"></el-input-number>
        </el-form-item>
        <el-form-item label="缴费" style="width: 400px">
          <el-input-number
            v-model="num"
            size="small"
            style="width: 200px"
          ></el-input-number>
        </el-form-item>
        <el-form-item label="有效期" style="width: 400px">
          <div>
            <el-radio-group v-model="lifespan" @input="lifespanChange" size="mini">
              <el-radio-button label="month">一月</el-radio-button>
              <el-radio-button label="year">一年</el-radio-button>
              <el-radio-button label="longTerm">长期</el-radio-button>
              <el-radio-button label="custom">自定义</el-radio-button>
            </el-radio-group>
          </div>
          <div>
            <el-date-picker
              v-model="createData.endDate"
              type="date"
              placeholder="选择日期"
              size="small"
            >
            </el-date-picker>
          </div>
        </el-form-item>
        <el-form-item label="课程顾问">
          <el-select
            v-model="createData.voucherId"
            filterable
            clearable
            placeholder="请选择"
            size="small"
          >
            <el-option
              v-for="item in voucherList"
              :key="item.id"
              :label="item.name"
              :value="item.id"
            >
            </el-option>
          </el-select>
        </el-form-item>
        <el-form-item label="备注" style="width: 400px">
          <el-input
            type="textarea"
            :rows="2"
            placeholder="请输入备注"
            v-model="createData.description"
          ></el-input>
        </el-form-item>
      </el-form>
      <span slot="footer" class="dialog-footer">
        <el-button @click="dialogVisible = false" size="small">取 消</el-button>
        <el-button type="primary" @click="dialogVisible = false" size="small"
          >确 定</el-button
        >
      </span>
    </el-dialog>
  </div>
</template>

<script>
import { getDetails, getSaleMan } from "@/api/student";

export default {
  filters: {
    statusFilter(status) {
      const statusMap = {
        published: "success",
        draft: "gray",
        deleted: "danger",
      };
      return statusMap[status];
    },
  },
  data() {
    return {
      dialogVisible: false,
      createData: {
        beginDate: new Date(),
        birthday: null,
        description: "",
        detailDescription: "",
        endDate: new Date(),
        amt: 0,
        freezeQty: 0,
        gender: "男",
        mobile: "",
        orgId: 25, //机构
        playerId: null,
        playerName: "",
        qty: 0,
        saleMan: {
          id: "",
          name: "",
        },
        staffId: JSON.parse(localStorage.getItem("selectStaff")).id,
        visibility: true,
        voucherId: "", //课包
      },
      saleManList: [],
      voucherList: [],
      lifespan:''
    };
  },
  created() {},
  methods: {
    showDialog() {
      this.dialogVisible = true;
    },
    getSaleManList() {
      let data = {
        staffId: JSON.parse(localStorage.getItem("selectStaff")).id,
        keyword: "",
        pageIn: {
          index: 0,
          size: 999,
          sorts: [
            {
              name: "name",
              direction: "ASC",
            },
            {
              name: "createTime",
              direction: "DESC",
            },
          ],
        },
      };
      getSaleMan(data).then((response) => {
        this.saleManList = response.data.findStaff.ls;
      });
    },
    goDetails(row) {
      this.$router.push("/details");
    },
    lifespanChange(val){
      console.log(val);
    }
  },
};
</script>
